<template>
  <view class="inspection-sheet">
    <!-- 头部信息 -->
    <view class="sheet-header">
      <h1>首检单</h1>
      <view class="inspection-number">检验单号：{{ formData.billNo }}</view>
    </view>

    <!-- 基本信息区 -->
    <view class="basic-info">
      <view class="info-row">
        <span class="info-label">创建时间：</span>
        <span class="info-value">{{ formData.createTime }}</span>
        <span class="info-label">负责人：</span>
        <span class="info-value">{{ formData.statusUser }}</span>
      </view>
    </view>

    <!-- 物料信息区 -->
    <view class="material-info">
      <view class="info-block">
        <view class="info-label">生产线别：</view>
        <view v-if="!isUpdate" class="info-value">{{ formData.line }}</view>
        <superwei-combox v-else v-model="formData.line" :candidates="DAA020List"
                         class="picker info-value-input" placeholder="请选择或输入"
                         @select="onDaa020Change"></superwei-combox>
      </view>
      <view class="info-block">
        <view class="info-label">物料编码：</view>
        <view v-if="!isUpdate" class="info-value">{{ formData.itemNo }}</view>
        <superwei-combox v-else v-model="formData.itemNo" :candidates="boardItems" :isJSON="true"
                         class="picker info-value-input" keyName="itemName" placeholder="请选择或输入"
                         @select="onItemChange"></superwei-combox>
      </view>
      <view class="info-block">
        <view class="info-label">计划编号：</view>
        <view v-if="!isUpdate" class="info-value">{{ formData.daa001 }}</view>
        <picker v-else :range="DAA001List" class="picker info-value-input" name="selector"
                @change="onDaa001Change">
          <view>{{ DAA001List[DAA001Index] }}</view>
        </picker>
      </view>
      <view class="info-block">
        <view class="info-label">产品名称：</view>
        <view class="info-value">{{ formData.daa003 }}</view>
      </view>
      <view class="info-block">
        <view class="info-label">规格型号：</view>
        <view class="info-value">{{ formData.daa004 }}</view>
      </view>
      <view class="info-block">
        <view class="info-label">工单数量：</view>
        <view class="info-value highlight">{{ formData.daa008 }}</view>
      </view>
      <view v-if="formData.remarks" class="info-block">
        <view class="info-label">备注：</view>
        <view class="info-value">{{ formData.remarks }}</view>
      </view>
    </view>

    <!-- 操作按钮区 -->
    <view v-if="isUpdate" class="action-buttons">
      <button class="secondary-btn" @click="getTable">获取检验项目</button>
    </view>

    <!-- 检验项目表格 -->
    <view v-if="tableData.length > 0" class="inspection-table">
      <!-- 表格头部统计信息 -->
      <view class="table-header-stats">
        <view class="stats-left">
          <view class="stats-title">检验项目清单</view>
          <view class="stats-subtitle">共 {{ tableData.length }} 个检验项目</view>
        </view>
        <view class="stats-right">
          <view class="stat-item passed">
            <span class="stat-count">{{ getPassedCount() }}</span>
            <span class="stat-label">已合格</span>
          </view>
          <view class="stat-item failed">
            <span class="stat-count">{{ getFailedCount() }}</span>
            <span class="stat-label">不合格</span>
          </view>
          <view class="stat-item pending">
            <span class="stat-count">{{ getPendingCount() }}</span>
            <span class="stat-label">待检验</span>
          </view>
        </view>
      </view>
      <table>
        <thead>
        <tr>
          <th style="text-align: center;" width="15%">检验项目</th>
          <th style="text-align: center;" width="50%">检验描述</th>
          <th style="text-align: center;" width="20%">记录(点击)</th>
        </tr>
        </thead>
        <tbody>
        <tr v-for="(item, index) in tableData" :key="index">
          <td>
            <view class="project-name-wrapper">
								<span :class="{
									'status-approved': item.result=='合格',
									'status-rejected': item.result=='不合格',
									'status-pending': item.result=='未完成'
								}" class="status-indicator"></span>
              {{ item.projName }}
            </view>
          </td>
          <td>
            <view v-if="item.result=='合格'" class="watermark approved">合格</view>
            <view v-if="item.result=='不合格'" class="watermark rejected">不合格</view>
            <view v-if="item.result=='未完成'" class="watermark pending">待确认</view>
            <view class="description-text">{{ item.itemMod }}</view>
          </td>
          <td>
            <button v-if="item.isCheck < item.levelNum" class="record-btn record-btn-fill"
                    @click="toDetail(item, index)">
              填写 ({{ item.isCheck }}/{{ item.levelNum }})
            </button>
            <button v-else class="record-btn record-btn-view" @click="toDetail(item, index)">
              查看 ({{ item.isCheck }}/{{ item.levelNum }})
            </button>
          </td>
        </tr>
        </tbody>
      </table>
    </view>

    <!-- 操作按钮区 -->
    <view class="action-buttons">
      <button v-if="isUpdate && !isShowTable" class="secondary-btn" @click="save">创建检验单并生成部分默认值</button>
      <button v-if="!isUpdate && !isShowTable" class="secondary-btn" @click="toImage">上传/查看图片</button>
      <button v-if="!isUpdate && !formData.statusUser && !isShowTable" class="secondary-btn" @click="removeXJ">
        删除单据
      </button>
      <button v-if="!isUpdate && !isShowTable" class="secondary-btn" @click="saveRemarks">添加备注</button>
      <button v-if="!isUpdate && !isShowTable && formData.fSubmit != 1" class="primary-btn" @click="submit">审核单据</button>
      <button v-if="isShowTable" class="secondary-btn" @click="getTable">获取检验项目</button>
      <button v-if="isShowTable && isUpdate" class="primary-btn" @click="saveTable">生成检验项目</button>
    </view>

    <!-- 弹窗 -->
    <view v-if="remarksPopup" class="overlay">
      <view class="popup">
        <h3>修改备注</h3>
        <form>
          <view class="form-group">
            <label class="form-label">备注:</label>
            <textarea v-model="remarks" class="form-input form-textarea" placeholder="请输入备注信息..."></textarea>
          </view>
          <button class="updateBut" @click="editRemarks">修改</button>
          <button @click="remarksPopup = !remarksPopup">取消</button>
        </form>
      </view>
    </view>
  </view>
</template>
<script>
export default {
  data() {
    return {
      formData: {
        createTime: "",
        id: "",
        billNo: "",
        itemNo: "",
        itemName: "",
        workshopCode: "",
        workshopName: "",
        line: "",
        lineName: "",
        comments: "",
        statusUser: "",
        itemId: "",
        fSubmit: 0,
      },

      DAA020List: [],

      DAA001List: [],
      schemeResult: [],
      DAA001Index: -1,

      ItemList: [],

      boardItems: [],

      womdaaList: [],

      tableData: [],

      isSubmit: true,

      isUpdate: true,

      isShowTable: false,

      remarks: "",
      remarksPopup: false,

      comments: "",
      commentsPopup: false,

    };
  },
  onLoad(options) {
    //options中包含了url附带的参数

    let params = options;

    if (params["id"]) {
      this.isUpdate = false;
      this.formData.id = params["id"];
      this.formData.billNo = params["billNo"];
      this.init();
    } else {
      //初始化检验单号
      this.$post({
        url: "/SJ/GetMaxBillNo"
      }).then(res => {
        this.formData.billNo = res.data.tbBillList;
        this.formData.createTime = this.$getDate("yyyy-mm-dd");
      });

      //产品编码下拉框的初始化
      this.$post({
        url: "/XJ/getLineAll"
      }).then(res => {
        this.lineList = res.data.tbBillList;
        this.DAA020List = res.data.tbBillList.map(item => item.lineName);
        this.formData.itemNo = "";
        this.formData.itemName = "";
        this.formData.workshopCode = "";
        this.formData.workshopName = "";
        this.formData.line = "";
        this.formData.lineName = "";
        this.formData.pbaid = null;
      })
    }
  },
  methods: {
    // 获取合格项目数量
    getPassedCount() {
      return this.tableData.filter(item => item.result === '合格').length;
    },
    // 获取不合格项目数量
    getFailedCount() {
      return this.tableData.filter(item => item.result === '不合格').length;
    },
    // 获取待检验项目数量
    getPendingCount() {
      return this.tableData.filter(item => item.result === '未完成').length;
    },
    removeXJ() {
      if (this.formData.id) {
        this.$post({
          url: "/SJ/removeSJ",
          data: {
            id: this.formData.id
          }
        }).then(res => {
          if (res.data.tbBillList > 0) {
            this.$showMessage("删除成功");
            //关闭当前页面，返回上一页面或多级页面
            uni.navigateBack();
          } else {
            this.$showMessage("删除失败");
          }
        });
      } else {
        this.$showMessage("请先选择检验单号");
      }
    },

    submit() {
      this.$post({
        url: "/SJ/SJQaSubmit",
        data: {
          userNo: this.$loginInfo.account,
          gid: this.formData.id
        }
      }).then(res => {

        //2024-11-28 kyy 校验合格提交增加提示
        console.log("完整响应数据:", res);
        console.log("Status Code的值:", res.statusCode);
        console.log("返回的数据:", res.data);
        
        // 检查多种成功条件
        if (res.statusCode === 200 || res.status === 0 || res.data === true || res.data.tbBillList === true) {

          this.$showMessage("成功提交检验");
          // 提交成功后跳转到列表页面
          setTimeout(() => {
            uni.navigateTo({
              url: '/pages/QC/SJ/List'
            });
          }, 1500); // 1.5秒后跳转，让用户看到成功提示
        } else {
          this.$showMessage(res.data.message || res.message || "提交失败");
        }
      }).catch(err => {
        console.log("提交出错:", err);
        this.$showMessage("提交失败，请重试");
      })
    },

    init() {
      if (this.formData.id) {
        this.$post({
          url: "/SJ/GetPage",
          data: {
            pageIndex: 1,
            limit: 1,
            id: this.formData.id
          }
        }).then(res => {
          let tbBillListElement = res.data.tbBillList[0];
          if (tbBillListElement) {
            this.formData = tbBillListElement;
            this.$post({
              url: "/SJ/getQSItems",
              data: {
                pid: this.formData.id
              }
            }).then(res => {
              this.tableData = res.data.tbBillList;

              this.tableData.sort((a, b) => {
                if (a.result === '未完成' && b.result === '合格') {
                  return -1;
                } else if (a.result === '合格' && b.result === '未完成') {
                  return 1;
                } else {
                  return 0;
                }
              });

              if (this.tableData.length <= 0) {
                this.isShowTable = true;
              }
            })
          }
        })
      }
    },
    onDaa020Change(event) {
      //获取生产线别的下标地址
      //this.formData.line = event;

      this.lineNo = this.lineList[this.DAA020List.indexOf(event)].lineNo;

      this.formData.line = this.lineNo;

      this.$post({
        url: "/XJ/getBoardItem",
        data: {
          lineNo: this.lineNo
        }
      }).then(res => {
        //填充工单号的数据源
        this.boardItems = res.data.tbBillList;

        this.ItemList = this.boardItems.map(item => item.itemName);
      })

    },
    onItemChange(event) {

      this.formData.itemNo = event.itemNo;

      this.$post({
        url: "/XJ/getDaa001",
        data: {
          daa020: this.lineNo,
          item: this.formData.itemNo
        }
      }).then(res => {
        //填充工单号的数据源
        this.schemeResult = res.data.tbBillList;
        this.DAA001List = this.schemeResult.map(s => s.daa001);
        //变为默认空值的状态
        this.DAA001Index = -1;
        this.formData.daa001 = "";
      })
    },
    //选取工单填充物料号和其他信息
    onDaa001Change(event) {
      this.DAA001Index = event.mp.detail.value;

      this.formData.daa001 = this.schemeResult[this.DAA001Index].daa001;

      //表单中的部分字段赋值
      this.$post({
        url: "/XJ/getItem",
        data: {
          daa001: this.formData.daa001
        }
      }).then(res => {
        let data = res.data.tbBillList[0];
        //当返回的结果集为空时置空原有的值
        if (!data) {
          this.formData.billNo = "";
          this.formData.taskNo = "";
          this.formData.itemNo = "";
          this.tableData = [];
          return;
        }
        //不为空时赋值
        this.formData.daa001 = data.daa001;
        this.formData.daa003 = data.daa003;
        this.formData.daa004 = data.daa004;
        this.formData.daa008 = data.daa008;
        this.formData.pbaid = data.id;


        this.$post({
          url: "/SJ/SetQSItems",
          data: {
            itemNo: this.formData.itemNo
          }
        }).then(res => {
          if (res.data.tbBillList.length > 0) {
            this.tableData = res.data.tbBillList; // 在箭头函数中，this 指向外层作用域的 this
            this.isSubmit = false;
          } else {
            this.$showMessage("此物料没有启用的检验项目，请维护!");
            this.isSubmit = true;
            this.tableData = [];
          }
        });

      });
    },
    toDetail(item, index) {
      if (this.isUpdate) {
        uni.showToast({
          icon: "none",
          title: "请先生成检验项目",
          duration: 2000,
        });
      } else {
        uni.navigateTo({
          url: 'detail?id=' + item.id + '&billNo=' + this.formData.billNo + '&gid=' + this.formData
              .id + '&index=' + index
        });
      }
    },
    getTable() {
      this.$post({
        url: "/SJ/SetQSItems",
        data: {
          itemNo: this.formData.itemNo
        }
      }).then(res => {
        if (res.data.tbBillList.length > 0) {
          this.tableData = res.data.tbBillList; // 在箭头函数中，this 指向外层作用域的 this
          this.isShowTable = true;
          this.isUpdate = true;
        } else {
          this.$showMessage("此物料没有启用的检验项目，请维护!");
          this.isShowTable = true;
          this.isUpdate = false;
          this.tableData = [];
        }
      });
    },
    saveTable() {
      if (this.tableData.length === 0) {
        return;
      }

      this.$post({
        url: "/SJ/SaveItem",
        data: {
          gid: this.formData.id,
          items: this.tableData,
          statusUser: this.$loginInfo.account
        }
      }).then(res => {
        this.tableData = res.data.tbBillList.items;
        this.isShowTable = false;
        this.isUpdate = false;
      })
    },
    save() {

      // if (this.tableData.length === 0) {
      // 	this.$showMessage(this.formData.itemNo + "物料没有检验项目");
      // 	return;
      // }

      if (!this.formData.daa001) {
        this.$showMessage("请选择计划编号");
        return;
      }

      this.formData.statusUser = this.$loginInfo.account;

      this.$post({
        url: "/SJ/Save",
        data: {
          from: this.formData,
          items: this.tableData
        }
      }).then(res => {
        this.formData = res.data.tbBillList.result;
        this.tableData = res.data.tbBillList.items;
        this.isUpdate = false;
      })
    },
    saveRemarks() {
      this.remarksPopup = !this.remarksPopup;
      this.remarks = this.formData.remarks;
    },
    saveComments() {
      this.commentsPopup = !this.commentsPopup;
      this.comments = this.formData.comments;
    },
    editRemarks() {
      if (this.remarks) {
        //saveRemarksGid
        this.$post({
          url: "/SJ/saveRemarksGid",
          data: {
            gid: this.formData.id,
            remarks: this.remarks
          }
        }).then(res => {
          if (res.data.tbBillList > 0) {
            this.formData.remarks = this.remarks;
            this.remarksPopup = !this.remarksPopup;
            this.$showMessage("保存成功");
          }
        })
      }
    },
    editComments() {
      if (this.comments) {
        //saveRemarksGid
        this.$post({
          url: "/SJ/saveCommentGid",
          data: {
            gid: this.formData.id,
            comments: this.comments
          }
        }).then(res => {
          if (res.data.tbBillList > 0) {
            this.formData.comments = this.comments;
            this.commentsPopup = !this.commentsPopup;
            this.$showMessage("保存成功");
          }
        })
      }
    },
    toImage() {
      uni.navigateTo({
        url: 'ImageItem?id=' + this.formData.id
      });
    }
  },
  onShow() {
    //每次进入页面都会执行的方法
    this.init();
  }
};
</script>

<style>
/* 基础样式 */
.inspection-sheet {
  font-family: 'Microsoft YaHei', 'Segoe UI', sans-serif;
  max-width: 1000px;
  margin: 0 auto;
  padding: 20px;
  background-color: #fff;
  box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
}

/* 头部样式 */
.sheet-header {
  text-align: center;
  margin-bottom: 20px;
  padding-bottom: 15px;
  border-bottom: 2px solid #e0e0e0;
}

.sheet-header h1 {
  color: #2c3e50;
  font-size: 24px;
  margin-bottom: 5px;
}

.inspection-number {
  font-size: 16px;
  font-weight: bold;
  color: #3498db;
}

/* 基本信息区样式 */
.basic-info,
.material-info {
  margin-bottom: 20px;
}

.info-row {
  display: flex;
  margin-bottom: 10px;
  flex-wrap: wrap;
}

.info-label {
  font-weight: bold;
  color: #34495e;
  min-width: 80px;
  margin-right: 5px;
}

.info-value {
  color: #2c3e50;
  margin-right: 20px;
}

.highlight {
  font-weight: bold;
  color: #e74c3c;
}

/* 物料信息区样式 */
.material-info {
  border: 1px solid #eee;
  padding: 15px;
  border-radius: 5px;
}

.info-block {
  display: flex;
  align-items: center;
  margin-bottom: 10px;
  flex-wrap: wrap;
}

.info-value-input {
  flex: 1;
  padding: 8px 12px;
  border: 1px solid #e9ecef;
  border-radius: 6px;
  background: #ffffff;
  font-size: 14px;
  margin-top: 6px;
}

.picker {
  width: 100%;
  padding: 8px 12px;
  border: 1px solid #e9ecef;
  border-radius: 6px;
  background: #ffffff;
  font-size: 14px;
  margin-top: 6px;
}

/* 表格样式 */
.inspection-table {
  margin: 25px 0;
  border-radius: 8px;
  overflow: hidden;
  box-shadow: 0 2px 8px rgba(0, 0, 0, 0.1);
  background: #fff;
}

/* 表格头部统计信息 */
.table-header-stats {
  display: flex;
  justify-content: space-between;
  align-items: center;
  padding: 16px 20px;
  background: linear-gradient(135deg, #f8f9fa, #e9ecef);
  border-bottom: 1px solid #e0e0e0;
}

.stats-left .stats-title {
  font-size: 18px;
  font-weight: bold;
  color: #2c3e50;
  margin-bottom: 4px;
}

.stats-left .stats-subtitle {
  font-size: 14px;
  color: #7f8c8d;
}

.stats-right {
  display: flex;
  gap: 16px;
}

.stat-item {
  display: flex;
  flex-direction: column;
  align-items: center;
  padding: 8px 12px;
  border-radius: 6px;
  min-width: 60px;
  box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
}

.stat-item.passed {
  background: linear-gradient(135deg, rgba(39, 174, 96, 0.1), rgba(39, 174, 96, 0.2));
  border: 1px solid rgba(39, 174, 96, 0.3);
}

.stat-item.failed {
  background: linear-gradient(135deg, rgba(230, 126, 34, 0.1), rgba(230, 126, 34, 0.2));
  border: 1px solid rgba(230, 126, 34, 0.3);
}

.stat-item.pending {
  background: linear-gradient(135deg, rgba(243, 156, 18, 0.1), rgba(243, 156, 18, 0.2));
  border: 1px solid rgba(243, 156, 18, 0.3);
}

.stat-count {
  font-size: 20px;
  font-weight: bold;
  line-height: 1;
  margin-bottom: 2px;
}

.stat-item.passed .stat-count {
  color: #27ae60;
}

.stat-item.failed .stat-count {
  color: #e67e22;
}

.stat-item.pending .stat-count {
  color: #f39c12;
}

.stat-label {
  font-size: 12px;
  color: #7f8c8d;
  font-weight: 500;
}

.inspection-table table {
  width: 100%;
  border-collapse: collapse;
}

.inspection-table th, .inspection-table td {
  padding: 16px 20px;
  border: none;
  text-align: left;
  border-bottom: 1px solid #eee;
}

.inspection-table th {
  background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);
  font-weight: 600;
  color: #fff;
  font-size: 14px;
  letter-spacing: 0.5px;
  position: relative;
}

.inspection-table tbody tr {
  transition: all 0.3s ease;
  border-left: 4px solid transparent;
}

.inspection-table tbody tr:nth-child(even) {
  background-color: #f8fafc;
}

.inspection-table tbody tr:hover {
  background-color: #e8f4fd;
  border-left-color: #3498db;
  transform: translateY(-1px);
  box-shadow: 0 4px 12px rgba(52, 152, 219, 0.15);
}

/* 检验项目列样式 */
.inspection-table td:first-child {
  font-weight: 600;
  color: #2c3e50;
  font-size: 15px;
}

/* 项目名称包装器 */
.project-name-wrapper {
  display: flex;
  align-items: center;
  gap: 8px;
}

/* 状态指示器 */
.status-indicator {
  width: 8px;
  height: 8px;
  border-radius: 50%;
  display: inline-block;
  flex-shrink: 0;
  box-shadow: 0 0 0 2px rgba(255, 255, 255, 0.8);
}

.status-indicator.status-approved {
  background-color: #27ae60;
  box-shadow: 0 0 0 2px rgba(39, 174, 96, 0.3);
}

.status-indicator.status-rejected {
  background-color: #e67e22;
  box-shadow: 0 0 0 2px rgba(230, 126, 34, 0.3);
}

.status-indicator.status-pending {
  background-color: #f39c12;
  box-shadow: 0 0 0 2px rgba(243, 156, 18, 0.3);
}

/* 检验描述列特殊样式 */
.inspection-table td:nth-child(2) {
  position: relative;
  min-height: 80px;
  vertical-align: top;
  padding: 16px 20px;
}

/* 按钮样式 */
.action-buttons {
  display: flex;
  justify-content: flex-end;
  gap: 10px;
  margin-top: 20px;
}

.primary-btn,
.secondary-btn {
  padding: 10px 20px;
  border: none;
  border-radius: 4px;
  font-size: 14px;
  cursor: pointer;
  transition: all 0.3s;
}

.primary-btn {
  background-color: #3498db;
  color: white;
}

.primary-btn:hover {
  background-color: #2980b9;
}

.secondary-btn {
  background-color: #ecf0f1;
  color: #7f8c8d;
}

.secondary-btn:hover {
  background-color: #d5dbdb;
}

.record-btn {
  padding: 8px 16px;
  background: linear-gradient(135deg, #3498db, #2980b9);
  color: #fff;
  border: none;
  border-radius: 6px;
  cursor: pointer;
  transition: all 0.3s ease;
  font-weight: 500;
  font-size: 13px;
  box-shadow: 0 2px 4px rgba(52, 152, 219, 0.3);
}

.record-btn:hover {
  background: linear-gradient(135deg, #2980b9, #1f618d);
  transform: translateY(-1px);
  box-shadow: 0 4px 8px rgba(52, 152, 219, 0.4);
}

.record-btn:active {
  transform: translateY(0);
}

/* 填写状态按钮 */
.record-btn-fill {
  background: linear-gradient(135deg, #2ecc71, #27ae60);
  box-shadow: 0 2px 4px rgba(46, 204, 113, 0.3);
}

.record-btn-fill:hover {
  background: linear-gradient(135deg, #27ae60, #229954);
  box-shadow: 0 4px 8px rgba(46, 204, 113, 0.4);
}

/* 查看状态按钮 */
.record-btn-view {
  background: linear-gradient(135deg, #95a5a6, #7f8c8d);
  box-shadow: 0 2px 4px rgba(149, 165, 166, 0.3);
}

.record-btn-view:hover {
  background: linear-gradient(135deg, #7f8c8d, #6c7b7d);
  box-shadow: 0 4px 8px rgba(149, 165, 166, 0.4);
}

/* 水印样式 */
.watermark {
  position: absolute;
  font-size: 32px;
  font-weight: bold;
  opacity: 0.4;
  z-index: 3;
  pointer-events: none;
  bottom: 8px;
  right: 8px;
  transform: rotate(-15deg);
  transform-origin: bottom right;
  text-shadow: 1px 1px 2px rgba(255, 255, 255, 0.8);
  min-width: 60px;
  text-align: center;
}

.watermark.approved {
  color: #27ae60; /* 更淡的绿色 */
}

.watermark.rejected {
  color: #e67e22; /* 更淡的红色 */
}

.watermark.pending {
  color: #f39c12; /* 橙色 */
}

/* 描述文本样式 */
.description-text {
  position: relative;
  z-index: 2;
  padding: 12px 16px;
  background: transparent;
  line-height: 1.6;
  font-size: 14px;
  color: #555;
  margin: 0;
  word-wrap: break-word;
  word-break: break-word;
  max-width: 100%;
  /* 确保文字不会太长遮挡水印 */
  padding-right: 80px;
  min-height: 20px;
  display: block;
}

.sysLike {
  color: #3498db;
  text-decoration: none;
  margin-left: 15px;
  padding: 3px 8px;
  border: 1px solid #3498db;
  border-radius: 3px;
  font-size: 12px;
}

.sysLike:hover {
  background-color: #f0f8ff;
}

/* 弹出层样式 */
.overlay {
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background-color: rgba(0, 0, 0, 0.5);
  display: flex;
  justify-content: center;
  align-items: center;
  z-index: 10;
}

.popup {
  background-color: #fff;
  padding: 20px;
  border: 1px solid #ccc;
  box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
  width: 85vw;
  min-height: 35vh;
  max-height: 60vh;
  border-radius: 8px;
}

.popup h3 {
  margin-top: 0;
  color: #2c3e50;
  border-bottom: 1px solid #eee;
  padding-bottom: 10px;
  margin-bottom: 15px;
  font-size: 16px;
  text-align: center;
}

.popup .form-group {
  margin-bottom: 15px;
  display: flex;
  flex-direction: column;
}

.popup .form-label {
  margin-bottom: 5px;
  font-weight: bold;
  font-size: 14px;
}

.popup .form-input {
  width: 100%;
  padding: 8px;
  border: 1px solid #ddd;
  border-radius: 4px;
  font-size: 14px;
  box-sizing: border-box;
}

.popup .form-textarea {
  min-height: 120px;
  resize: vertical;
  font-family: inherit;
  line-height: 1.5;
}

.popup-buttons {
  display: flex;
  justify-content: flex-end;
  gap: 10px;
  margin-top: 20px;
}

.updateBut {
  background-color: #3498db;
  color: white;
  border: none;
  padding: 8px 15px;
  border-radius: 4px;
  margin-right: 10px;
  cursor: pointer;
  transition: all 0.3s;
}

.updateBut:hover {
  background-color: #2980b9;
}

/* 响应式设计 */
@media (max-width: 500px) {
  .info-row,
  .info-block {
    flex-direction: column;
    align-items: flex-start;
  }

  .action-buttons {
    flex-direction: column;
  }

  /* 移动端表格头部统计 */
  .table-header-stats {
    flex-direction: column;
    gap: 12px;
    align-items: flex-start;
    padding: 12px 16px;
  }

  .stats-right {
    width: 100%;
    justify-content: space-around;
    gap: 8px;
  }

  .stat-item {
    flex: 1;
    min-width: auto;
    padding: 6px 8px;
  }

  .stat-count {
    font-size: 16px;
  }

  .stat-label {
    font-size: 11px;
  }

  .stats-left .stats-title {
    font-size: 16px;
  }

  .stats-left .stats-subtitle {
    font-size: 13px;
  }

  .inspection-table {
    margin: 15px -10px;
    border-radius: 0;
  }

  .inspection-table th,
  .inspection-table td {
    padding: 12px 8px;
    font-size: 13px;
  }

  .inspection-table th {
    font-size: 12px;
  }

  .description-text {
    padding: 8px 12px;
    padding-right: 50px;
    font-size: 13px;
  }

  .record-btn {
    padding: 6px 12px;
    font-size: 12px;
  }

  /* 移动端水印样式调整 */
  .watermark {
    font-size: 24px;
    bottom: 4px;
    right: 4px;
  }

  /* 移动端表格hover效果减弱 */
  .inspection-table tbody tr:hover {
    transform: none;
    box-shadow: none;
  }

  /* 移动端状态指示器调整 */
  .project-name-wrapper {
    gap: 6px;
  }

  .status-indicator {
    width: 6px;
    height: 6px;
  }

  /* 移动端弹出框优化 */
  .popup {
    width: 95vw;
    min-height: 40vh;
    max-height: 70vh;
    padding: 15px;
  }

  .popup .form-textarea {
    min-height: 100px;
  }
}

/* 平板设备样式 */
@media (min-width: 501px) and (max-width: 768px) {
  .watermark {
    font-size: 28px;
    bottom: 6px;
    right: 6px;
  }

  .inspection-table th,
  .inspection-table td {
    padding: 14px 16px;
  }

  .description-text {
    font-size: 14px;
    padding-right: 70px;
  }

  .record-btn {
    padding: 7px 14px;
    font-size: 13px;
  }
}

/* 大屏设备优化 */
@media (min-width: 1200px) {
  .inspection-table {
    margin: 30px 0;
  }

  .watermark {
    font-size: 36px;
    bottom: 10px;
    right: 10px;
  }
}
</style>